@@ -14,6 +14,7 @@
 
 #include <ModemManagerQt/Manager>
 
+#include <NetworkManagerQt/GenericDevice>
 #include <NetworkManagerQt/Settings>
 
 NetworkModel::NetworkModel(QObject *parent)
@@ -213,6 +214,10 @@ void NetworkModel::initialize()
         if (!dev->managed()) {
             continue;
         }
+        // TODO implement loopback device in NetowrkManagerQt
+        if (dev->interfaceName() == QLatin1String("lo")) {
+            continue;
+        }
         addDevice(dev);
     }
 
